<!-- markdownlint-disable -->

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\timestamp.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.timestamp`





---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\timestamp.py#L22"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `time_since`

```python
time_since(timestamp: utils.timestamp.TimeStamp | float) → float
```

Calculate the elapsed time since the given TimeStamp or time value. 


---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\timestamp.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `TimeStamp`
A TimeStamp object that can be used to track the time since it was created. 

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\timestamp.py#L7"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `TimeStamp.__init__`

```python
__init__() → None
```








---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\timestamp.py#L10"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `TimeStamp.time_since`

```python
time_since() → float
```

Calculate the elapsed time since this TimeStamp was created or updated. 

---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\timestamp.py#L14"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `TimeStamp.update`

```python
update() → None
```

Update the TimeStamp to the current time. 




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
